@@ -695,7 +695,7 @@ defi_dovs_table = """
 
 futures_basis_hist = """
     query HistoricalIntradayTradedWeightedBasis($exchange: ExchangeEnumType, $symbol: SymbolEnumType, $expiration: String, $dateStart: String, $dateEnd: String) {
-      HistoricalIntradayTradedWeightedBasis: HistoricalIntraDayTradedBasis: genericHistoricalIntraDayTradedBasis(exchange: $exchange, symbol: $symbol, expiration: $expiration, dateStart: $dateStart, dateEnd: $dateEnd) {
+      HistoricalIntradayTradedWeightedBasis: genericHistoricalIntraDayTradedBasis(exchange: $exchange, symbol: $symbol, expiration: $expiration, dateStart: $dateStart, dateEnd: $dateEnd) {
         date
         expiration
         amount
@@ -1169,3 +1169,37 @@ defi_zeta_orderbook = """
        }
     }
 """
+
+
+##ADDED AGAIN ON CUSTOMER'S REQUESTS
+
+CustomMaturityDeltaSurface = """
+    query CustomMaturityDeltaSurface($symbol: BTCOrETHEnumType, $date: String, $days: Float) {
+      CustomMaturityDeltaSurface: CustomMaturityAtmDelta(symbol: $symbol, date: $date, days: $days) {
+        date
+        p05
+        p15
+        p25
+        p35
+        atm
+        c05
+        c15
+        c25
+        c35
+      }
+    }
+"""
+
+HourlyInstrumentImpliedVolandOI = """
+    query HourlyInstrumentImpliedVolandOI($symbol: BTCOrETHEnumType, $dateStart: String, $dateEnd: String, $strike: String, $putCall: PutCallEnumType, $expiration: String) {
+      HourlyInstrumentImpliedVolandOI: InstrumentOiIv1Hr(symbol: $symbol, dateStart: $dateStart, dateEnd: $dateEnd, strike: $strike, putCall: $putCall, expiration: $expiration) {
+        date
+        instrumentName
+        oi
+        bidIV
+        markIV
+        askIV
+      }
+    }
+"""
+
